@@ -34,7 +34,7 @@ class Message:
 class Categories(Enum):
     ESTIMATION = "estimation"
     IDENTITY = "identity"
-    PROJECT = "project"
+    PROJECTS = "projects"
 
 
 class Commands(Enum):
